/**
 * @class AS.ARC.apps.syslogServer FolderSelector
 * @extends Ext.container.Container
 * <p></p> 
 */
Ext.define('AS.ARC.apps.syslogServer.FolderSelector', {
	extend: 'AS.ARC.subWindow',
	
	apiUrl: null,
	
	title: _S('COMMON', 'BROWSE'),
	
	parentWin: null,
	
	pathCmp: null,
	
	width: 500,
	
	height: 400,
	
	layout: 'fit',
	
	initComponent: function () {
		var me = this;
		
		me.apiUrl = me.apiUrl || AS.ARC.util.getApiUrl('fileExplorer.cgi', 'fileExplorer');
		
		me.addEvents({
			exception: true,
			selectionchange: true
		});
		
		me.buttonApply = Ext.create('Ext.button.Button', {
			text: _S('COMMON', 'OK'),
			disabled: true,
			handler: function () {
				var path = me.getValue();
				
				if (path && me.pathCmp) {
					me.pathCmp.setValue(path.substring(1));
				}
				
				me.close();
			},
			scope: me
		});
		
		me.buttonCancel = Ext.create('Ext.button.Button', {
			text: _S('COMMON', 'CANCEL'),
			handler: function () {
				me.close();
			}
		});
		
		var treeStore = Ext.create('Ext.data.TreeStore', {
			autoLoad: false,
			autoDestroy: true,
			fields: [{
				name: 'file_path'
			}, {
				name: 'id',
				mapping: 'file_path'
			}, {
				name: 'filename',
				convert: function(v) {
					return Ext.htmlEncode(v);
				}
			}, {
				name: 'path',
				mapping: 'file_path'
			}, {
				name: 'iconCls',
				convert: function(v, record) {
					var cls = 'app-syslogServer-tree-item-dir-icon';

					return cls;
				}
			}],
			defaultRootId: '',
			nodeParam: 'path',
			proxy: {
				type: 'ajax',
				url: AS.ARC.util.getApiUrlWithSid(me.apiUrl, {act: 'file_list'}),
				method: 'post',
				extraParams: {
					onlydir: true,
					showhome: true
				},
				actionMethods: {
					create: 'POST', 
					read: 'POST', 
					update: 'POST', 
					destroy: 'POST'
				},
				reader: {
					type: 'json',
					root: 'data'
				},
				listeners: {
					exception: function (proxy, response, operation, opts) {
						me.fireEvent('exception', proxy, response, operation, opts);
					}
				}
			}
		});
		
		me.tree = Ext.create('Ext.tree.TreePanel', {
			rootVisible: false,
			useArrows : true,
			autoScroll: true,
			border: false,
			resizable: false,
			store: treeStore,
			displayField: 'filename',
			animate: false,
			anchor: '0 -15',
			getSelection: function () {
				return this.getSelectionModel().getSelection();
			},
			
			listeners: {
				selectionchange: function (sm, selections) {
					me.fireEvent('selectionchange', sm, selections);
					
					if (selections.length > 0) {
						me.buttonApply.enable();
					} else {
						me.buttonApply.disable();
					}
				}
			}
		});
		
		Ext.apply(me, {
			items: [{
				xtype: 'asPanelTop10',
				layout: 'anchor',
				items: me.tree
			}],
			fbar: [
				me.buttonApply,
				me.buttonCancel,
			]
		});
		
		me.callParent();
	},
	
	getValue: function () {
		var me = this;
		
		var selections = me.tree.getSelection();
			
		if (selections.length > 0) {
			return selections[0].data.path;
		}
		
		return null;
	}
});

Ext.define('AS.ARC.apps.syslogServer.archive.main', {
    extend: 'AS.ARC.apps.syslogServer.page',
	pageTag: 'main',
    imgUrl: AS.ARC.util.getUserAppsPath() + 'syslogServer/images/',
    
    handleApply: function() {
		var page = this,
			urlOpts = {
				act: 'Archive',
            	tab: 'Set_Setting'
			},
			params = page.fp.doDataExchange();

		if (!page.fp.isSettingChange(params)) {
			page.fp.showSetNotChange();
			return false;
		} // end if

		page.fn.app.maskWin(_S('COMMON', 'APPLYING'));
		
        AS.ARC.ajax({
            url: AS.ARC.util.getApiUrlWithSid(page.fn.apiUrl, urlOpts),
            method: 'post',
            params: params,
            success: function(json, opts) {
                page.fp.uiChecker.srcData = params;
				page.fp.showApply();
				page.fn.app.unmaskWin();
            },
            failure: function(json, opts) {
                var errors = {
                    5000: _S('ERROR', 'SESSION_TIMEOUT'),
					5401: _S('ERROR', 'UNABLE_APPLY_SETTINGS')
                };
				
				page.fn.app.unmaskWin();
                AS.ARC.util.showMsgWindow(errors, json, page.fn.app.win, 'warning', function() {page.loadData();});
            }
		});
	},
    
	getPanel: function() {
		var page = this;

		var archiveLogNameValidator = function(value) {
			if (value.startsWith(' ') || value.endsWith(' ')) {
				return _S('MESSAGE', 'HF00014');
            } else if (/[\/]+/.test(value)) {
                return Ext.String.format(_S('MESSAGE', 'HF00028'), '\/');
            } else {
				return true;
			}
		};

        page.buttonApply = Ext.create('Ext.button.Button', {
			xtype: 'button',
			text: _S('COMMON', 'APPLY')
		});
		
		return {
			xtype: 'asFnForm',
			page: page,
			itemId: page.panelItemId,
            title: _S('SYSLOG_SERVER', 'ARCHIVE'),
			border: false,
			cls: 'as-page-panel',
            buttonAlign: 'left',
			fbar: [
				{
					xtype: 'tbfill'
				},
				page.buttonApply
			],
			items: [
				{
					xtype: 'fieldset',
					itemId: 'preserveFileFieldset',
					title: _S('SYSLOG_SERVER', 'ARCHIVE'),
					items: [
						{
							xtype: 'container',
							itemId: 'preservePathContainer',
							layout: 'hbox',
							width: 660,
							defaults: {
								margin: '0 3 0 0'
							},
							items: [
								{
									xtype: 'textfield',
									itemId: 'path',
									readOnly: true,
									labelWidth: 201,
									width: 406,
									fieldLabel: _S('SYSLOG_SERVER', 'DEFAULT_PATH')
								}, 
								{
									xtype: 'button',
									minWidth: 100,
									text: _S('COMMON', 'BROWSE'),
									handler: function(btn) {
										var fs = Ext.create('AS.ARC.apps.syslogServer.FolderSelector', {
											parentWin: page.fn.app.win,
											pathCmp: btn.prev()
										}).show();

										fs.buttonApply.handler = function() {
											var path = fs.getValue();

											if (path && fs.pathCmp) {
												fs.pathCmp.setValue(path);
											}

											fs.close();
										};

										fs.buttonCancel.handler = function() {
											fs.close();
										};
									}
								}
							]
						}, 
						{
							xtype: 'container',
							itemId: 'preserveFormatContainer',
							layout: 'hbox',
							width: 660,
							defaults: {
								margin: '0 3 0 0'
							},
							items: [
								{
									xtype: 'textfield',
									itemId: 'name',
									maxLength: 32,
									allowBlank: false,
									blankText: _S('MESSAGE', 'HF00011'),
									msgTarget: AS.ARC.config.msgTarget,
									maxLengthText: Ext.String.format(_S('MESSAGE', 'HF00016'), '32'),
									maskRe: /[^`#$%\*+=\[\]|\\:;"'<>,?\/]/,
									width: 306,
									labelWidth: 201,
									fieldLabel: _S('SYSLOG_SERVER', 'LOG_NAME_FORMAT'),
									validator: archiveLogNameValidator
								}, 
								{
									xtype: 'combobox',
									itemId: 'format',
									width: 200,
									store: {
										fields: ['value', 'text'],
										data: [
											{'value':0, 'text':'YYYYMMDDhhmm'},
											{'value':1, 'text':'mmhhDDMMYYYY'},
										]
									},
									editable: false,
									value: 0,
									triggerAction: 'all',
									valueField: 'value',
									displayField: 'text'
								}
							]
						}
					]
				}, 
				{
					xtype: 'fieldset',
					itemId: 'preserveRuleFieldset',
					width: 678,
					title: _S('SYSLOG_SERVER', 'AUTO_SAVE'),
					items: [
						{
							xtype: 'container',
							itemId: 'countRuleContainer',
							layout: 'hbox',
							width: 660,
							defaults: {
								margin: '0 3 0 0'
							},
							items: [
								{
									xtype: 'combobox',
									itemId: 'preserveCountValue',
									store: {
										fields: ['value', 'text'],
										data: [
											{'value':1, 'text':'10,000'},
											{'value':2, 'text':'30,000'},
											{'value':3, 'text':'50,000'},
											{'value':4, 'text':'100,000'},
											{'value':5, 'text':'300,000'},
											{'value':6, 'text':'500,000'},
											{'value':7, 'text':'1,000,000'},
											{'value':8, 'text':'3,000,000'},
											{'value':9, 'text':'5,000,000'},
											{'value':10, 'text':'10,000,000'}
										]
									},
									editable: false,
									value: 6,
									triggerAction: 'all',
									valueField: 'value',
									displayField: 'text',
									width: 386,
									labelWidth: 201,
									fieldLabel: _S('SYSLOG_SERVER', 'LOG_COUNT_LARGER_THAN')
								}
							]
						}, 
						{
							xtype: 'container',
							itemId: 'sizeRuleContainer',
							layout: 'hbox',
							defaults: {
								margin: '0 3 0 0'
							},
							items: [
								{
									xtype: 'checkbox',
									itemId: 'preserveSizeCheckbox',
									boxLabel: _S('SYSLOG_SERVER', 'LOG_SIZE_LARGER_THAN'),
									width: 200,
									handler: function(checkbox, checked) {
										if (checked) {
											page.logPreserveSizeForValue.enable();
										} else {
											page.logPreserveSizeForValue.disable();
										}
									}
								}, 
								{
									xtype: 'combobox',
									itemId: 'preserveSizeValue',
									width: 180,
									store: {
										fields: ['value', 'text'],
										data: [
											{'value':1, 'text':'100MB'},
											{'value':2, 'text':'300MB'},
											{'value':3, 'text':'500MB'},
											{'value':4, 'text':'1GB'}
										]
									},
									editable: false,
									value: 1,
									triggerAction: 'all',
									valueField: 'value',
									displayField: 'text'
								}
							]
						}, 
						{
							xtype: 'container',
							itemId: 'periodRuleContainer',
							layout: 'hbox',
							width: 660,
							defaults: {
								margin: '0 3 0 0'
							},
							items: [
								{
									xtype: 'checkbox',
									itemId: 'preservePeriodCheckbox',
									boxLabel: _S('SYSLOG_SERVER', 'EARLIER_THAN'),
									width: 200,
									handler: function(checkbox, checked) {
										if (checked) {
											page.logPreservePeriodForValue.enable();
										} else {
											page.logPreservePeriodForValue.disable();
										}
									}
								}, 
								{
									xtype: 'combobox',
									itemId: 'preservePeriodValue',
									width: 180,
									store: {
										fields: ['value', 'text'],
										data: [
											{'value':1, 'text': _S('SYSLOG_SERVER', 'ONE_MONTH')},
											{'value':2, 'text': _S('SYSLOG_SERVER', 'THREE_MONTH')},
											{'value':3, 'text': _S('SYSLOG_SERVER', 'SIX_MONTH')},
											{'value':4, 'text': _S('SYSLOG_SERVER', 'ONE_YEAR')}
										]
									},
									editable: false,
									value: 1,
									triggerAction: 'all',
									valueField: 'value',
									displayField: 'text'
								}
							]
						}
					]
				}
			],
			doDataExchange: function() {
				var preservePath = page.logPreservePath.getValue(),
					preserveName = page.logPreserveName.getValue(),
					preserveFormat = page.logPreserveFormat.getValue(),
					preserveCount = page.logPreserveCountForValue.getValue(),
					preserveSize,
					preservePeriod;

				preserveSize = page.logPreserveSizeForCheckbox.checked ? page.logPreserveSizeForValue.getValue() : 0;

				preservePeriod = page.logPreservePeriodForCheckbox.checked ? page.logPreservePeriodForValue.getValue() : 0;

				var pageData = {
                    archive_location: preservePath,
                    archive_name: preserveName,
                    archive_format: preserveFormat,
					archive_size: preserveSize,
                    archive_number: preserveCount,
                    archive_date: preservePeriod
				};
                
				return pageData;
			}
		};
	},

	loadData: function() {
		var page = this;

		page.fn.app.maskWin(_S('COMMON', 'LOADING'));

		page.logPreservePath = page.fn.tabPanel.down('#path');
		page.logPreserveName = page.fn.tabPanel.down('#name');
		page.logPreserveFormat = page.fn.tabPanel.down('#format');
		page.logPreserveSizeForCheckbox = page.fn.tabPanel.down('#preserveSizeCheckbox');
		page.logPreserveSizeForValue = page.fn.tabPanel.down('#preserveSizeValue');
		page.logPreserveCountForValue = page.fn.tabPanel.down('#preserveCountValue');
		page.logPreservePeriodForCheckbox = page.fn.tabPanel.down('#preservePeriodCheckbox');
		page.logPreservePeriodForValue = page.fn.tabPanel.down('#preservePeriodValue');

		AS.ARC.ajax({
            url: AS.ARC.util.getApiUrlWithSid(page.fn.apiUrl, {act: 'Archive', tab: 'Get_Setting'}),
            method: 'post',
            success: function(json, opts) {
				page.fp.uiChecker.srcData = json;

				var logPreserveSizeRuleDisable,
					logPreservePeriodRuleDisable;

				logPreserveSizeRuleDisable = json.archive_size === 0;
				logPreservePeriodRuleDisable = json.archive_date === 0;

				page.logPreservePath.setValue(json.archive_location);
				page.logPreserveName.setValue(json.archive_name);
				page.logPreserveFormat.setValue(json.archive_format);
				page.logPreserveCountForValue.setValue(json.archive_number);

				if (logPreserveSizeRuleDisable) {
                    page.logPreserveSizeForCheckbox.setValue(false);
                    page.logPreserveSizeForValue.setValue(1);
                    page.logPreserveSizeForValue.disable();
                } else {
                    page.logPreserveSizeForCheckbox.setValue(true);
                    page.logPreserveSizeForValue.setValue(json.archive_size);
                    page.logPreserveSizeForValue.enable();
				}
				
				if (logPreservePeriodRuleDisable) {
                    page.logPreservePeriodForCheckbox.setValue(false);
                    page.logPreservePeriodForValue.setValue(1);
                    page.logPreservePeriodForValue.disable();
                } else {
                    page.logPreservePeriodForCheckbox.setValue(true);
                    page.logPreservePeriodForValue.setValue(json.archive_date);
                    page.logPreservePeriodForValue.enable();
				}
				
				page.fn.app.unmaskWin();
            },
            failure: function(json, opts) {
				page.fn.app.unmaskWin();
				AS.ARC.util.showMsgWindow({}, json, page.fn.app.win);
            }
        });
	}
});

/**
 * @class AS.ARC.apps.syslogServer.archive.fn
 * @extends AS.ARC.apps.syslogServer.fn
 * <p></p>
 */
Ext.define('AS.ARC.apps.syslogServer.archive.fn', {
	extend: 'AS.ARC.apps.syslogServer.fn',

	fnTag: 'archive',
	
	init: function (config) {
		this.apiUrl = AS.ARC.util.getUserAppsPath() + 'syslogServer/syslog-server.cgi',
		this.createPanel();
	},
    
	createPanel: function () {
		var fn = this;
		
		var pageArchive = new AS.ARC.apps.syslogServer.archive.main({fn: this});
			
		this.tabPanel = Ext.create('AS.ARC.fnTabPanel', {
			items: [
				pageArchive.getPanel()
			]
		});
        
		fn.initMainPanel();
	},
	
	loadData: function () {
		this.tabPanel.activeTab.page.loadData(true);
	}
});