/**
 * File selector
 */
Ext.define('AS.ARC.apps.syslogServer.fileSelector', {
	extend: 'Object',
	
	path: [],
	fullPath: '',
	phyPath: [],
	fullPhyPath: '',
	// For select iso file
	isoOnly: false,
	backName: '',
	backPath: [],
	
	disableMyArchive: false,

	constructor: function (config) {
		Ext.apply(this, config);
		this.callParent();
		
		this.init();		
		this.createWindow();
	},
	
	init: function () {
		this.path = [];
		this.fullPath = '';
		
		this.phyPath = [];
		this.fullPhyPath = '';
	},
	
	getGridFileStore: function (path) {
		var fs = this;
		
		var urlOpts = {
			act: 'file_list',
			path: path,
		};
		
		return Ext.create('Ext.data.JsonStore', {
			autoDestroy: true,
			fields: [
				{name: 'text', mapping: 'filename'},
				{name: 'filesize', mapping: 'file_size'},
				{name: 'type', mapping: 'extension_type'},
				{name: 'path', mapping: 'file_path'}
			],
			pageSize: 1000,
			proxy: {
				type: 'ajax',
				url: AS.ARC.util.getApiUrlWithSid(AS.ARC.util.getApiUrl('fileExplorer.cgi', 'fileExplorer'), urlOpts),
				reader: {
					type: 'json',
					root: 'data'
				},
				extraParams: {
					showhome: true,
					sortway: 'filename',
					dirway: 'ASC'
				}
			},
			listeners: {
				load : function (ds, o, a) {
					if(fs.backName != '') {
						var index = 0;
						ds.each(function(element) {
							if(element.data.text == fs.backName) {
								return false;
							}
							index++;
						});
						
						fs.backName = '';
						
						if (index < ds.getCount()) {
							if (fs.path.length < 1) {
								fs.gridTree.selModel.select(index);
							}else{
								setTimeout(function(){
									fs.gridFile.selModel.select(index);
								},10);
							}
						}
					}

					fs.gridFile.el.dom.querySelector('.x-panel-body').scrollTop = 0;
				}
			}
		});
	},
	
	getFullPath: function () {
		return '/' + this.path.join('/');
	},
	
	getFullPhyPath: function() {
		//return '/' + this.phyPath.join('/');
		
		var fullPhyPath = '';
		
		for(var i = 0; i < this.phyPath.length; i ++) {
			fullPhyPath = fullPhyPath + this.phyPath[i] + '/';
		}
		
		return fullPhyPath;
		//return '/' + this.phyPath.join('/');
	},
	
	loadGridFile: function (path) {
		var fs = this;
		
		fs.storeFile = fs.getGridFileStore(path);
		fs.gridFile.reconfigure(fs.storeFile);
		fs.storeFile.load();
		
	},

	setVirtualPath: function(path) {
		var fs = this;

		fs.fullPath = path;
	},
	
	checkNavi: function () {
		var fs = this;
		
		// Disable button Ok
		fs.buttonOk.disable();
		
		if (fs.path.length > 0) {
			fs.buttonBack.enable(true);
			fs.mainGrids.layout.setActiveItem(1);
			
			// Update locatoin bar
			fs.locatoinBar.setValue(fs.getFullPath() );
		} else {
			fs.buttonBack.enable(false);
			fs.mainGrids.layout.setActiveItem(0);
			
			// Update locatoin bar
			fs.locatoinBar.setValue('/');
		}
	},
	//define media type
	MEDIA_TYPE_3G2: '3g2',
	MEDIA_TYPE_3GP: '3gp',
	MEDIA_TYPE_ASF: 'asf',
	MEDIA_TYPE_ASX: 'asx',
	MEDIA_TYPE_AVI: 'avi',
	MEDIA_TYPE_FLV: 'flv',
	MEDIA_TYPE_M3U: 'm3u',
	MEDIA_TYPE_M4A: 'm4a',
	MEDIA_TYPE_MKV: 'mkv',
	MEDIA_TYPE_MOV: 'mov',
	MEDIA_TYPE_MP3: 'mp3',
	MEDIA_TYPE_MP4: 'mp4',
	MEDIA_TYPE_MPA: 'mpa',
	MEDIA_TYPE_MPEG: 'mpeg',
	MEDIA_TYPE_MPG: 'mpg',
	MEDIA_TYPE_REC: 'rec',
	MEDIA_TYPE_RM: 'rm',
	MEDIA_TYPE_RMVB: 'rmvb',
	MEDIA_TYPE_VOB: 'vob',
	MEDIA_TYPE_WMV: 'wmv',
	MEDIA_TYPE_WSF: 'wsf',
	//define img type
	IMG_TYPE_JPG: 'jpg',
	IMG_TYPE_PNG: 'png',
	IMG_TYPE_GIF: 'gif',
	IMG_TYPE_BMP: 'bmp',
	IMG_TYPE_EPS: 'eps',
	IMG_TYPE_JPEG: 'jpeg',
	IMG_TYPE_TIF: 'tif',
	//define office type	
	OFFICE_TYPE_TXT: 'txt',
	OFFICE_TYPE_EXCEL: 'excel',
	OFFICE_TYPE_HTML: 'html',
	OFFICE_TYPE_PDF: 'pdf',
	OFFICE_TYPE_POWERPOINT: 'power-point',
	OFFICE_TYPE_WORD: 'word',
	OFFICE_TYPE_XML: 'xml',
	OFFICE_TYPE_DOC: 'doc',
	OFFICE_TYPE_DOCX: 'docx',
	OFFICE_TYPE_XLSX: 'xlsx',
	OFFICE_TYPE_XLS: 'xls',
	OFFICE_TYPE_PPTX: 'pptx',
	OFFICE_TYPE_PPT: 'ppt',
	//define compress type
	COMPRESS_TYPE_7Z: '7z',
	COMPRESS_TYPE_ZIP: 'zip',
	COMPRESS_TYPE_RAR: 'rar',
	COMPRESS_TYPE_GZ: 'gz',
	//define mount type
	MOUNT_TYPE_EXE: 'exe',
	MOUNT_TYPE_ISO:'iso',
	createWindow: function () {
		var fs = this;
		var typearray = [ 
			fs.MEDIA_TYPE_3G2 , 
			fs.MEDIA_TYPE_3GP, 
			fs.MEDIA_TYPE_ASF,
			fs.MEDIA_TYPE_ASX,
			fs.MEDIA_TYPE_AVI,
			fs.MEDIA_TYPE_FLV,
			fs.MEDIA_TYPE_M3U,
			fs.MEDIA_TYPE_M4A,
			fs.MEDIA_TYPE_MKV,
			fs.MEDIA_TYPE_MOV,
			fs.MEDIA_TYPE_MP3,
			fs.MEDIA_TYPE_MP4,
			fs.MEDIA_TYPE_MPA,
			fs.MEDIA_TYPE_MPEG,
			fs.MEDIA_TYPE_MPG,
			fs.MEDIA_TYPE_REC,
			fs.MEDIA_TYPE_RM,
			fs.MEDIA_TYPE_RMVB,
			fs.MEDIA_TYPE_VOB,
			fs.MEDIA_TYPE_WMV,
			fs.MEDIA_TYPE_WSF,
			fs.IMG_TYPE_JPG,
			fs.IMG_TYPE_PNG,
			fs.IMG_TYPE_GIF,
			fs.IMG_TYPE_BMP,
			fs.IMG_TYPE_EPS,
			fs.IMG_TYPE_JPEG,
			fs.IMG_TYPE_TIF,
			fs.OFFICE_TYPE_DOC,
			fs.OFFICE_TYPE_DOCX,
			fs.OFFICE_TYPE_TXT,
			fs.OFFICE_TYPE_EXCEL,
			fs.OFFICE_TYPE_XLSX,
			fs.OFFICE_TYPE_XLS,
			fs.OFFICE_TYPE_HTML,
			fs.OFFICE_TYPE_PDF,
			fs.OFFICE_TYPE_POWERPOINT,
			fs.OFFICE_TYPE_PPTX,
			fs.OFFICE_TYPE_PPT,
			fs.OFFICE_TYPE_WORD,
			fs.OFFICE_TYPE_XML,
			fs.COMPRESS_TYPE_7Z,
			fs.COMPRESS_TYPE_ZIP,
			fs.COMPRESS_TYPE_RAR,
			fs.COMPRESS_TYPE_GZ,
			fs.COMPRESS_TYPE_TAR,
			fs.COMPRESS_TYPE_WIM,
			fs.COMPRESS_TYPE_GZIP,
			fs.MOUNT_TYPE_ISO,
			fs.MOUNT_TYPE_EXE
			
		];
		var typeUrl = [ 
			'3G2.png',
			'3gp.png',
			'asf.png',
			'asx.png',
			'avi.png',
			'flv.png',
			'm3u.png',
			'm4a.png',
			'mkv.png',
			'mov.png',
			'mp3.png',
			'mp4.png',
			'mpa.png',
			'mpeg.png',
			'mpg.png',
			'rec.png',
			'rm.png',
			'rmvb.png',
			'vob.png',
			'wmv.png',
			'wsf.png',
			'jpg.png',
			'png.png',
			'gif.png',
			'bmp.png',
			'eps.png',
			'jpeg.png',
			'tif.png',
			'word.png',
			'word.png',
			'txt.png',
			'excel.png',
			'excel.png',
			'excel.png',
			'html.png',
			'pdf.png',
			'power-point.png',
			'power-point.png',
			'power-point.png',
			'word.png',
			'xml.png',
			'7z.png',
			'zip.png',
			'rar.png',
			'gz.png',
			'tar.png',
			'wim.png',
			'gzip.png',
			'iso.png',
			'exe.png'
			
		];
		fs.storeTree = Ext.create('Ext.data.JsonStore', {
			autoDestroy: true,
			fields: [
				{name: 'text', mapping: 'filename'},
				{name: 'id', mapping: 'file_path'},
				{name: 'phy_path', mapping: 'physical_path'}
			],
			pageSize: 1000,
			proxy: {
				type: 'ajax',
				url: AS.ARC.util.getApiUrlWithSid(AS.ARC.util.getApiUrl('fileExplorer.cgi', 'fileExplorer'), {act:'file_list'}),
				reader: {
					type: 'json',
					root: 'data'
				},
				extraParams: {
					showhome: true,
					path: '/'
				}
			},
			listeners: {
				load: function (ds, o, a) {
					if (fs.disableMyArchive) {
						var myarchive1 = '/volume1/MyArchive1',
							myarchive2 = '/volume1/MyArchive2';
						ds.filter([{
							filterFn: function (item) {								
								if (item.get('phy_path') === myarchive1 ||
									item.get('phy_path') === myarchive2) {
									return false;
								} else {
									return true;
								}
						}
						}]);
					}

					if(fs.backName != '') {
						var index = 0;
						ds.each(function(element) {
							if(element.data.text == fs.backName) {
								return false;
							}
							index++;
						});
						fs.backName = '';
						if (index < ds.getCount()) {
							if (fs.path.length < 1) {
								fs.gridTree.selModel.select(index);
							}else{
								setTimeout(function(){
									fs.gridFile.selModel.select(index);
								},10);
							}
						}
					}

					fs.gridTree.el.dom.querySelector('.x-panel-body').scrollTop = 0;
				}
			}
		});
		
		fs.gridTree = Ext.create('Ext.grid.GridPanel', {
			itemId: 'grid-tree',
			height: 250,
			border: 0,
			columns: [{
				text: _S('COMMON', 'NAME'),
				sortable: false,
				dataIndex: 'text',
				flex: 1,
				draggable: false,
				renderer: function (value, cell, record, rowIndex, columnIndex, store) {
					var result = '';			
					var name = value;	
					result = '<img src="apps/fileExplorer/images/files_list/folder_close.png" style="width:20px; height:20px; float: left; margin-top:-4px; margin-left:2px;" >&nbsp;<span style="margin-top: -4px;">&nbsp; '+ name+'</span>';
					
					return result;
				}
			}],
			store: fs.storeTree,
			listeners: {
				render: function () {
					fs.storeTree.load();
				},
				itemdblclick: function (view, record, item, index, e, eOpts) {
					//_D('itemdblclick');
					// Add to path
					fs.path.push(record.get('text') );
					fs.backPath.push(record.get('id'));
					
					if (fs.phyPath.length < 1) {
						fs.phyPath.push(record.get('phy_path'));
					} else {
						fs.phyPath.push(record.get('text'));
					}
					
					// Go to file grid
					fs.mainGrids.layout.setActiveItem(1);
					
					// Load grid
					fs.loadGridFile(record.get('id') );
					
					// Check navi bar
					fs.checkNavi();
				},
				scope: fs
			}
		});
		
		fs.storeFile = fs.getGridFileStore('/');
		fs.backRecord = '';
		fs.gridFile = Ext.create('Ext.grid.GridPanel', {
			itemId: 'grid-file',
			height: 240,
			width: 455,
			border: 0,
			columns: [{
				text: _S('COMMON', 'NAME'),
				sortable: false,
				dataIndex: 'text',
				flex: 1,
				draggable: false,
				renderer: function (value, cell, record, rowIndex, columnIndex, store) {
					var result = '',
						value = value.replace(/\u0020/ig, '&nbsp;'),
						name = value;
					//_D('record.data.type.toLowerCase():'+record.data.type.toLowerCase());
					if (record.data.type.toLowerCase() == 'dir') {
						result = '<img src="apps/fileExplorer/images/files_list/folder_close.png" style="width:20px; height:20px; float: left; margin-top:-4px; margin-left:2px;" >&nbsp;<span style="margin-top: -4px;">&nbsp; '+ name+'</span>';
						
					} else {
						var length = typearray.length;						
						for(var i=0; i < length; i++) {
							if(record.data.type.toLowerCase() == typearray[i]){
								result = '<img src="apps/fileExplorer/images/files_list/'+typeUrl[i] + '" style="width:20px; height:20px; float: left; margin-top:-4px; margin-left:2px;" >&nbsp;<span style="margin-top: -4px;">&nbsp; '+ name+'</span>';
								break;
							}else{
								result = '<img src="apps/fileExplorer/images/files_list/unknow.png" style="width:20px; height:20px; float: left; margin-top:-4px; margin-left:2px;" >&nbsp;<span style="margin-top: -4px;">&nbsp; '+ name+'</span>';
							}
						}
						
					}
					cell.tdAttr = 'data-qtip="' + value + '"';
					return result;
				}
			}, {
				text: _S('COMMON', 'SIZE'),
				sortable: false,
				dataIndex: 'filesize',
				width: 100,
				draggable: false,
				renderer: function (value, cell, record, rowIndex, columnIndex, store) {
					if (record.get('type') === 'dir') {
						return '';
					} else {
						return AS.ARC.util.convertSizeUnit(value);
					}
				}
			}, {
				text: _S('COMMON', 'TYPE'),
				sortable: false,
				dataIndex: 'type',
				width: 100,
				draggable: false,
				renderer: function (value, cell, record, rowIndex, columnIndex, store) {
					return value;
				}
			}],
			store: fs.storeFile,
			listeners: {
				render: function () {
					//fs.storeFile.load();
				},
				itemclick : function (view, record, item, index, e, eOpts) {
					var okEnable = false;
					
					// if select directory
					if (record.get('type') !== 'dir') {
						// if select iso file
						if (fs.isoOnly) {
							if (/.\.db/.test(record.get('text').toLowerCase() ) ) {
								
								okEnable = true;
							}
						} else {
							okEnable = true;
						}
					}
					
					if (okEnable) {
						fs.buttonOk.enable();
					} else {
						fs.buttonOk.disable();
					}
				},
				itemdblclick: function (view, record, item, index, e, eOpts) {
					_D('itemdblclick - ' + record.get('text'));
					fs.backRecord = record;
					_D('back index - ' + fs.backRecord.get('text'));
					if (record.get('type') === 'dir') {
						// Add to path
						fs.path.push(record.get('text') );
						fs.backPath.push(record.get('path'));
						
						if (fs.phyPath.length < 1) {
							fs.phyPath.push(record.get('phy_path'));
						} else {
							fs.phyPath.push(record.get('text'));
						}
						
						fs.storeFile = fs.getGridFileStore(record.get('path'));
						fs.gridFile.reconfigure(fs.storeFile);
						fs.storeFile.load();
						
						// Check navi bar
						fs.checkNavi();
					} else if (fs.isoOnly) {
						if (/.\.db/.test(record.get('text').toLowerCase() ) ) {
							// return selected path
							fs.setVirtualPath(record.get('path'));
							fs.fullPhyPath = fs.getFullPhyPath() + record.get('text');
							
							fs.handleOk(fs.parentOpts);
							fs.win.close();
						}
					} else {
						// return selected path
						fs.setVirtualPath(record.get('path'));
						fs.fullPhyPath = fs.getFullPhyPath() + record.get('text');
						
						fs.handleOk(fs.parentOpts);
						fs.win.close();
					}
				},
				scope: fs
			}
		});
		
		fs.mainGrids = Ext.create('Ext.panel.Panel', {
			region: 'center',
			itemId: 'main-grids',
			
			border: 0,
			layout: 'card',
			activeItem: 0,
			items: [
				fs.gridTree,
				fs.gridFile
			]		
		});
		
		fs.buttonBack = Ext.create('Ext.Img', {
			width: 39,
			height: 31,
			baseCls: "as-imgBtn-fileChooser",
			enabled: false,

			imgNormal: "resources/images/accessControl/browseBtn_normal.png",
			imgPress: "resources/images/accessControl/browseBtn_press.png",
			imgHover: "resources/images/accessControl/browseBtn_over.png",
			imgDisable: "resources/images/accessControl/browseBtn_normal.png",

			enable: function (enable){
				var btn = this;
				btn.enabled = enable;
				btn.onNormal();
			},

			iniEvent: function(){
				var btn = this;
				Ext.fly(this.el).on('click', function(e, t) {
					btn.onClick();
				});
				Ext.fly(this.el).on('mousedown', function(e, t) {
					btn.onPress();
				});
				Ext.fly(this.el).on('mouseup', function(e, t) {
					btn.onNormal();
				});
				Ext.fly(this.el).on('mouseover', function(e, t) {
					btn.onHover();
				});
				Ext.fly(this.el).on('mouseout', function(e, t) {
					btn.onNormal();
				});
			},

			onClick: function () {
				var btn = this;
				if (btn.enabled) {
					fs.backflag = true;
					fs.backName = fs.path.splice((fs.path.length - 1), 1);
					_D('back index - ' + fs.backRecord )
					// Check navi bar
					fs.checkNavi();
					if (fs.backPath.length < 1) {
						fs.storeTree.load();
					} else {
						fs.backPath.pop();
						fs.loadGridFile(fs.backPath[fs.backPath.length - 1]);
					}
				}
			},

			onPress: function(){
				var btn = this;

				var img = btn.imgPress;
				if( !btn.enabled ){
					img = btn.imgDisable;
				}// end if
				btn.setSrc(img);
			},

			onHover: function(){
				var btn = this;

				var img = btn.imgHover;
				if( !btn.enabled ){
					img = btn.imgDisable;
				}// end if
				btn.setSrc(img);
			},

			onNormal: function(){
				var btn = this;
				var img = btn.imgNormal;
				if( !btn.enabled ){
					img = btn.imgDisable;
				}// end if
				btn.setSrc(img);
			},

			listeners: {
				render: function( com, eOpts ) {
					var btn = this;
					btn.iniEvent();
					btn.enable( btn.enabled );
				}
			}
		});
		
		fs.buttonOk = Ext.create('Ext.button.Button', {
			text: _S('COMMON', 'OK'),
			scale: AS.ARC.config.defaultActionButtonSize,
			disabled: true,
			handler: function () {
				// return selected path
				var selections = fs.gridFile.getSelectionModel().getSelection();

				fs.setVirtualPath(selections[0].data.path);
				fs.fullPhyPath = fs.getFullPhyPath()  + selections[0].data.text;
				
				fs.handleOk(fs.parentOpts);
				fs.win.close();
			},
			scope: fs
		});
		
		fs.buttonCancel = Ext.create('Ext.button.Button', {
			text: _S('COMMON', 'CANCEL'),
			scale: AS.ARC.config.defaultActionButtonSize,
			handler: function () {
				fs.win.close();
			},
			scope: fs
		});
		
		fs.locatoinBar = Ext.create('Ext.form.TextField', {
			value: '/',
			flex: 1
		});
		
		fs.win = Ext.create('AS.ARC.subWindow', {
			parentWin: fs.parentWin,
			title: _S('COMMON', 'BROWSE'),
			width: 500,
			height: 440,
			fbar: [
				fs.buttonOk,
				fs.buttonCancel
			],
			items: [{
				xtype: 'asPanelTop10',
				itemId: 'main-panel',
				height: 300,
				items: [{
					xtype: 'container',
					layout: 'hbox',
					flex: 1,
					items: [
						fs.buttonBack,
						fs.locatoinBar
					]
				},
					fs.mainGrids
				]
			}]
		});
	}
});


Ext.define('AS.ARC.apps.syslogServer.log.log', {
    extend: 'AS.ARC.apps.syslogServer.page',
	pageTag: 'log',
	imgUrl: AS.ARC.util.getUserAppsPath() + 'syslogServer/images/',
	logShowCount: 30,

	exportSyslogData: function(exportFormat) {
		var page = this;

		var download = Ext.create('Ext.form.FormPanel', {
				items: [{xtype: 'filefield'}]
			}),
			uform = download.getForm();

		var doSubmit = function() {
			var exportParams = {
					act: 'List', 
					tab: 'Export', 
					format: exportFormat
				},
				logGridExtraParams = page.logGrid.store.getProxy().extraParams,
				urlOpts;

			urlOpts = Ext.apply(logGridExtraParams, exportParams);

			uform.submit({
				url: AS.ARC.util.getApiUrlWithSid(page.fn.apiUrl, urlOpts),
				success: function(fp, o) {

				},
				failure: function(form, action) {
					var json = Ext.decode(action.response.responseText);
					AS.ARC.util.showMsgWindow({
						5000: _S('ERROR', 'SESSION_TIMEOUT'), 
						5005: _S('COMMON', 'EMPTY_NO_DATA')
					}, json, page.fn.app.win);
				}
			});
		};

		doSubmit();
	},

	getPanel: function () {
		var page = this;

		var getAdvanceSearchWin = function() {
			var advanceSearchWin = Ext.create('AS.ARC.subWindow', {
				itemId: 'advanceSearchWin',
				title: _S('SYSLOG_SERVER', 'ADVANCED_SEARCH'),
				width: 550,
				height: 500,
				layout: 'fit',
				parentWin: page.fn.app.win,
				fbar: [
					{
						xtype: 'button',
						itemId: 'search',
						text: _S('SYSLOG_SERVER', 'SEARCH'),
						handler: function() {
							var advanceSearchKeywordValue = page.advanceSearchKeywordItem.getValue(),
								advanceSearchDeviceValue = page.advanceSearchDeviceItem.getValue(),
								advanceSearchLevelValue = page.advanceSearchLevelItem.getValue(),
								advanceSearchFacilityValue = page.advanceSearchFacilityItem.getValue(),
								advanceSearchTimeValue = page.advanceSearchTimeItem.getValue(),
								advanceSearchStartTimeValue = page.advanceSearchStartTimeItem.getSubmitValue(),
								advanceSearchEndTimeValue = page.advanceSearchEndTimeItem.getSubmitValue(),
								advanceSearchPrognameValue = page.advanceSearchPrognameItem.getValue(),
								logGridAdvanceSearchParams = {};

							if (advanceSearchKeywordValue !== '') {
								Ext.apply(logGridAdvanceSearchParams, {
									msg: advanceSearchKeywordValue
								});
							}

							if (advanceSearchDeviceValue !== '') {
								Ext.apply(logGridAdvanceSearchParams, {
									fromhostname: advanceSearchDeviceValue
								});
							}

							if (advanceSearchLevelValue !== '') {
								Ext.apply(logGridAdvanceSearchParams, {
									level: advanceSearchLevelValue
								});
							}

							if (advanceSearchFacilityValue !== '') {
								Ext.apply(logGridAdvanceSearchParams, {
									facility: advanceSearchFacilityValue
								});
							}

							if (advanceSearchTimeValue !== 0) {
								Ext.apply(logGridAdvanceSearchParams, {
									time: advanceSearchTimeValue
								});
							}

							if (advanceSearchTimeValue === 4 && advanceSearchStartTimeValue !== '') {
								Ext.apply(logGridAdvanceSearchParams, {
									start_time: advanceSearchStartTimeValue
								});
							}

							if (advanceSearchTimeValue === 4 && advanceSearchEndTimeValue !== '') {
								Ext.apply(logGridAdvanceSearchParams, {
									end_time: advanceSearchEndTimeValue
								});
							}

							if (advanceSearchPrognameValue !== '') {
								Ext.apply(logGridAdvanceSearchParams, {
									progname: advanceSearchPrognameValue
								});
							}

							if (Ext.Object.getKeys(logGridAdvanceSearchParams).length === 0) {
								Ext.apply(logGridAdvanceSearchParams, {
									search: 0
								});
							} else {
								Ext.apply(logGridAdvanceSearchParams, {
									search: 1
								});
							}

							if (page.logGrid.store.getProxy().extraParams.logfile) {
								Ext.apply(logGridAdvanceSearchParams, {
									logfile: page.logGrid.store.getProxy().extraParams.logfile
								});
							}

							page.logGrid.store.getProxy().extraParams = logGridAdvanceSearchParams;
							page.logGrid.store.load();
							advanceSearchWin.close();
						}
					}, 
					{
						xtype: 'button',
						text: _S('SYSLOG_SERVER', 'RESET'),
						handler: function() {
							page.advanceSearchKeywordItem.setValue('');
							page.advanceSearchDeviceItem.setValue('');
							page.advanceSearchLevelItem.setValue('');
							page.advanceSearchFacilityItem.setValue('');
							page.advanceSearchTimeItem.setValue(0);
							page.advanceSearchStartTimeItem.setValue('');
							page.advanceSearchEndTimeItem.setValue('');
							page.advanceSearchPrognameItem.setValue('');

							page.advanceSearchStartTimeItem.disable();
							page.advanceSearchEndTimeItem.disable();
						}
					}, 
					{
						xtype: 'button',
						text: _S('COMMON', 'CANCEL'),
						handler: function() {
							advanceSearchWin.close();
						}
					}
				],
				items: [
					{
						xtype: 'panel',
						itemId: 'container',
						bodyStyle: 'padding: 15px;',
						//style: 'background-color: white;',
						items: [
							{
								xtype: 'textfield',
								labelWidth: 200,
								itemId: 'keyword',
								fieldLabel: _S('SYSLOG_SERVER', 'KEYWORD'),
							}, 
							{
								xtype: 'combobox',
								itemId: 'device',
								store: {
									fields: ['fromhostname'],
									data: []
								},
								queryMode: 'local',
								fieldLabel: _S('SYSLOG_SERVER', 'DEVICE'),
								labelWidth: 200,
								editable: false,
								value: '',
								triggerAction: 'all',
								valueField: 'fromhostname',
								displayField: 'fromhostname'
							}, 
							{
								xtype: 'combobox',
								itemId: 'level',
								store: {
									fields: ['value', 'text'],
									data: [
										{'value': '', 'text': _S('COMMON', 'ALL')},
										{'value':'0', 'text': _UN_TS('Emergency')},
										{'value':'1', 'text': _UN_TS('alert')},
										{'value': '2', 'text': _UN_TS('critical')},
										{'value': '3', 'text': _UN_TS('error')},
										{'value': '4', 'text': _UN_TS('warning')},
										{'value': '5', 'text': _UN_TS('notice')},
										{'value': '6', 'text': _UN_TS('info')},
										{'value': '7', 'text': _UN_TS('debug')}
									]
								},
								fieldLabel: _S('SYSLOG_SERVER', 'LEVEL'),
								labelWidth: 200,
								editable: false,
								value: '',
								triggerAction: 'all',
								valueField: 'value',
								displayField: 'text'
							}, 
							{
								xtype: 'combobox',
								itemId: 'facility',
								store: {
									fields: ['value', 'text'],
									data: [
										{'value': '', 'text': _S('COMMON', 'ALL')},
										{'value':'0', 'text': _UN_TS('kern')},
										{'value':'1', 'text': _UN_TS('user')},
										{'value':'2', 'text': _UN_TS('mail')},
										{'value':'3', 'text': _UN_TS('daemon')},
										{'value':'4', 'text': _UN_TS('auth')},
										{'value':'5', 'text': _UN_TS('syslog')},
										{'value':'6', 'text': _UN_TS('lpr')},
										{'value':'7', 'text': _UN_TS('news')},
										{'value':'8', 'text': _UN_TS('uucp')},
										{'value':'9', 'text': _UN_TS('cron')},
										{'value':'10', 'text': _UN_TS('security')},
										{'value':'11', 'text': _UN_TS('ftp')},
										{'value':'12', 'text': _UN_TS('ntp')},
										{'value':'13', 'text': _UN_TS('logaudit')},
										{'value':'14', 'text': _UN_TS('logalert')},
										{'value':'15', 'text': _UN_TS('clock')},
										{'value':'16', 'text': _UN_TS('local0')},
										{'value':'17', 'text': _UN_TS('local1')},
										{'value':'18', 'text': _UN_TS('local2')},
										{'value':'19', 'text': _UN_TS('local3')},
										{'value':'20', 'text': _UN_TS('local4')},
										{'value':'21', 'text': _UN_TS('local5')},
										{'value':'22', 'text': _UN_TS('local6')},
										{'value':'23', 'text': _UN_TS('local7')}
									]
								},
								fieldLabel: _S('SYSLOG_SERVER', 'FACILITY'),
								labelWidth: 200,
								editable: false,
								value: '',
								triggerAction: 'all',
								valueField: 'value',
								displayField: 'text'
							},
							{
								xtype: 'combobox',
								itemId: 'time',
								store: {
									fields: ['value', 'text'],
									data: [
										{'value': 0, 'text': _S('COMMON', 'ALL')},
										{'value': 1, 'text': _S('SYSLOG_SERVER', 'PAST_ONE_DAY')},
										{'value': 2, 'text': _S('SYSLOG_SERVER', 'PAST_WEEK')},
										{'value': 3, 'text': _S('SYSLOG_SERVER', 'PAST_MONTH')},
										{'value': 4, 'text': _S('SYSLOG_SERVER', 'CUSTOMIZATION')}
									]
								},
								fieldLabel: _S('SYSLOG_SERVER', 'TIME_PERIOD'),
								labelWidth: 200,
								editable: false,
								value: 0,
								triggerAction: 'all',
								valueField: 'value',
								displayField: 'text',
								listeners: {
									change: function(combo, value) {
										if (value == 4) {
											advanceSearchWin.items.get('container').items.get('startTime').enable();
											advanceSearchWin.items.get('container').items.get('endTime').enable();
										} else {
											advanceSearchWin.items.get('container').items.get('startTime').disable();
											advanceSearchWin.items.get('container').items.get('endTime').disable();
										}
									}
								}
							}, 
							{
								xtype: 'datefield',
								format: 'Y-m-d',
								itemId: 'startTime',
								disabled: true,
								style: 'margin-left: 10px',
								fieldLabel: _S('SYSLOG_SERVER', 'START_TIME'),
								labelWidth: 190,
								editable: false
							}, 
							{
								xtype: 'datefield',
								format: 'Y-m-d',
								itemId: 'endTime',
								disabled: true,
								style: 'margin-left: 10px',
								fieldLabel: _S('SYSLOG_SERVER', 'END_TIME'),
								labelWidth: 190,
								editable: false
							}, 
							{
								xtype: 'textfield',
								itemId: 'progname',
								fieldLabel: _S('SYSLOG_SERVER', 'PROGNAME'),
								labelWidth: 200
							}
						]
					}
				],
				listeners: {
					afterrender: function() {
						page.advanceSearchKeywordItem = advanceSearchWin.down('#keyword');
						page.advanceSearchDeviceItem = advanceSearchWin.down('#device');
						page.advanceSearchLevelItem = advanceSearchWin.down('#level');
						page.advanceSearchFacilityItem = advanceSearchWin.down('#facility');
						page.advanceSearchTimeItem = advanceSearchWin.down('#time');
						page.advanceSearchStartTimeItem = advanceSearchWin.down('#startTime');
						page.advanceSearchEndTimeItem = advanceSearchWin.down('#endTime');
						page.advanceSearchPrognameItem = advanceSearchWin.down('#progname');

						advanceSearchWin.el.mask(_S('COMMON','LOADING'));
					},
					beforeshow: function() {
						var advanceSearchDeviceComboBox = advanceSearchWin.down('#device');

						AS.ARC.ajax({
							url: AS.ARC.util.getApiUrlWithSid(page.fn.apiUrl, {act: 'Overview', tab: 'Group', group: 1}),
							method: 'get',
							success: function(json, opts) {
								var deviceData = json.device;

								advanceSearchDeviceStore = advanceSearchDeviceComboBox.getStore();
								advanceSearchDeviceStore.loadData(deviceData);
								advanceSearchWin.el.unmask();
							},
							failure: function(json, opts) {
								advanceSearchWin.el.unmask();
							}
						});
					}
				}
			});
			
			advanceSearchWin.show();
		};

		var handleLogPathDisplay = function(path) {
			logTopCt.items.get('import').setText(path);
			logTopCt.items.get('import').el.dom.setAttribute('data-qtip', path);

			var importButtonWidth = logTopCt.down('#import').btnEl.getWidth(),
				importButtonInnerTextWidth = logTopCt.down('#import').btnInnerEl.getTextWidth(),
				isInnerTextOverButton = importButtonInnerTextWidth > importButtonWidth;

			logTopCt.down('#import').btnInnerEl.dom.style.display = 'inline-block';
			logTopCt.down('#import').btnInnerEl.dom.style.width = 'auto';
			logTopCt.down('#import').btnInnerEl.dom.style.position = 'relative';

			if (isInnerTextOverButton) {
				logTopCt.down('#import').btnInnerEl.dom.style.left = importButtonWidth - importButtonInnerTextWidth;
			} else {
				logTopCt.down('#import').btnInnerEl.dom.style.left = (importButtonInnerTextWidth - importButtonWidth) / 2;
			}
		};
        
        var logTopCt = Ext.create('AS.ARC.panelToolbarTop', {
			itemId: 'log-topct',
			layout: 'hbox',
			items: [
				{
					xtype: 'button',
					itemId: 'export',
					text: _S('SYSLOG_SERVER', 'EXPORT'),
					handler: function() {
						var format = 'csv';

						page.exportSyslogData(format);
					}
				},
				{
					xtype: 'splitbutton',
					itemId: 'import',
					cls: 'importButton',
					text: _S('SYSLOG_SERVER', 'LATEST_LOG'),
					minWidth: 300,
					maxWidth: 300,
					onClick: function() {
						var btn = this;

						// Menu would show at wrong position. If create at definition.
						// Because of this. Creating menu when btn be pressed.
						btn.menu = null;

						var importMenuArray = [];
						
						importMenuArray.push(
							{
								xtype: 'menuitem',
								text: _S('SYSLOG_SERVER', 'LATEST_LOG'),
								icon: page.imgUrl + 'last_log.png',
								minWidth: 300,
								handler: function() {
									page.logGrid.store.getProxy().extraParams = {
										tab: 'List'
									};

									page.logGrid.store.loadPage(1);

									logTopCt.items.get('import').setText(_S('SYSLOG_SERVER', 'LATEST_LOG'));
									logTopCt.items.get('import').el.dom.setAttribute('data-qtip', _S('SYSLOG_SERVER', 'LATEST_LOG'));
								}
							},
							{
								xtype: 'menuitem',
								text: _S('SYSLOG_SERVER', 'OPEN_LOG_FROM_ARCHIVE'),
								icon: page.imgUrl + 'archive_log.png',
								minWidth: 300,
								handler: function() {
									var fs = Ext.create('AS.ARC.apps.syslogServer.fileSelector', {
										isoOnly: true,
										parentWin: page.fn.app.win,
										disableMyArchive: true,
										handleOk: function(opts) {
											var archiveLogFileSelector = this,
												archiveLogVirtualPath = archiveLogFileSelector.fullPath;

											var params = {
												tab: 'List',
												logfile: archiveLogVirtualPath
											};

											page.logGrid.store.getProxy().extraParams = params;

											page.logGrid.store.loadPage(1);

											handleLogPathDisplay(archiveLogVirtualPath);
											
											page.fp.el.unmask();
										}
									});

									fs.buttonCancel.handler = function() {
										fs.win.close();
									}

									fs.win.show();
								}
							}
						);
						
						AS.ARC.ajax({
							url: AS.ARC.util.getApiUrlWithSid(AS.ARC.util.getUserAppsPath() + 'syslogServer/syslog-server.cgi', {act: 'List', tab: 'get_browsing_record'}),
							method: 'post',
							success: function(json, opts) {
								for (var i = 0; i < json.record.length; i++) {
									if (json.record[i] !== '') {
										var text = json.record[i];

										importMenuArray.push(
											{
												xtype: 'menuitem',
												cls: 'app-syslogServer-menu',
												text: text,
												logfile: json.record[i],
												minWidth: 300,
												width: 300,
												handler: function(item) {
													var params = {
														tab: 'List',
														logfile: item.logfile
													};

													page.logGrid.store.getProxy().extraParams = params;

													page.logGrid.store.loadPage(1);

													handleLogPathDisplay(item.text);
												},
												listeners: {
													render: function(item) {
														item.el.dom.setAttribute('data-qtip', item.text);
													}
												}
											}
										);
									}
								}
								
								if (!btn.menu) {
									btn.menu = new Ext.menu.Menu({
										items: importMenuArray
									});
								}// end if

								btn.menu.showBy(btn, 'tl-bl');
							},
							failure: function(json, opts) {
								if (!btn.menu) {
									btn.menu = new Ext.menu.Menu({
										items: importMenuArray
									});
								}// end if

								btn.menu.showBy(btn, 'tl-bl');
							}
						});
					}
				}, 
				{
					xtype: 'button',
					itemId: 'clean',
					text: _S('COMMON', 'CLEAR'),
					handler: function() {
						var confirmWin = new AS.ARC.msgWindow({
							title: _S('COMMON', 'CONFIRMATION'),
							width: 400,
							parentWin: page.fn.app.win,
							iconType: 'question',
							asItems: [
								{
									xtype: 'displayfield',
									itemId: 'removeLogRecordConfirmText',
									value: _S('SYSTEMINFORMATION', 'NOTE_REMOVE_LOG')
								}
							],
							fbar: [
								{
									text: _S('COMMON', 'YES'),
									handler: function() {
										var removeLogRecordParams = {act: 'List', tab: 'Clean'},
											isRemoveArchiveLog = page.logGrid.store.getProxy().extraParams.logfile;

										if (isRemoveArchiveLog) {
											Ext.apply(removeLogRecordParams, {
												logfile: page.logGrid.store.getProxy().extraParams.logfile
											});
										}

										AS.ARC.ajax({
											url: AS.ARC.util.getApiUrlWithSid(AS.ARC.util.getUserAppsPath() + 'syslogServer/syslog-server.cgi', removeLogRecordParams),
											method: 'post',
											success: function(json, opts) {
												page.logGrid.store.getProxy().extraParams = {
													tab: 'List'
												};
	
												page.logGrid.store.loadPage(1);
													
												logTopCt.down('#import').setText(_S('SYSLOG_SERVER', 'LATEST_LOG'));
												logTopCt.down('#import').el.dom.setAttribute('data-qtip', _S('SYSLOG_SERVER', 'LATEST_LOG'));
											},
											failure: function(json, opts) {

											}
										});

										confirmWin.close();
									},
									scope: this
								},
								{
									text: _S('COMMON', 'NO'),
									handler: function() {
										confirmWin.close();
									},
									scope: this
								}
							],
							listeners: {
								afterrender: function() {
									var isRemoveArchiveLog = page.logGrid.store.getProxy().extraParams.logfile;

									if (isRemoveArchiveLog) {
										confirmWin.down('#removeLogRecordConfirmText').setValue(_S('SYSLOG_SERVER', 'DELETE_ARCHIVE_LOG_CONFIRM'));
									}
								}
							}
						});

						confirmWin.show();
					}
				}, 
				{
					xtype: 'tbfill'
				}, 
				{
					xtype: 'button',
					itemId: 'advanceSearchBtn',
					text: _S('SYSLOG_SERVER', 'ADVANCED_SEARCH'),
					handler: function() {
						getAdvanceSearchWin();
					}
				}
			]
		});

		page.logGrid = Ext.create('Ext.grid.Panel', {
			itemId: 'grid',
			height: 400,
			width: '100%',
			cls: 'as-grid',
			border: false,
			autoScroll: true,
			columns: [
				{
					dataIndex: 'time',
					flex: 2,
					header: _S('REGIONAL', 'DATE_TIME'),
					renderer: function(value, metadata, record) {
						metadata.tdAttr = 'data-qtip="' + value + '"';
						
						return value;
					}
				}, 
				{
					dataIndex: 'level',
					flex: 1,
					header: _S('SYSLOG_SERVER', 'LEVEL'),
					renderer: function(value, metadata, record) {
						var str;
						
						switch(value) {
							case 0: str = _UN_TS('Emergency');
									break;
							case 1: str = _UN_TS('Alert');
									break;
							case 2: str = _UN_TS('Critical');
									break;
							case 3: str = _UN_TS('Error');
									break;
							case 4: str = _UN_TS('Warning');
									break;
							case 5: str = _UN_TS('Notice');
									break;
							case 6: str = _UN_TS('Info');
									break;
							case 7: str = _UN_TS('Debug');
									break;
						}
						
						metadata.tdAttr = 'data-qtip="' + str + '"';

						return str;
					}
				}, 
				{
					dataIndex: 'fromhostname',
					flex: 1,
					header: _S('SYSLOG_SERVER', 'DEVICE'),
					renderer: function(value, metadata, record) {
						metadata.tdAttr = 'data-qtip="' + value + '"';
						
						return value;
					}
				}, 
				{
					dataIndex: 'facility',
					flex: 1,
					header: _S('SYSLOG_SERVER', 'FACILITY'),
					renderer: function(value, metadata, record) {
						var str;

						switch(value) {
							case 0: str = _UN_TS('kern');
									break;
							case 1: str = _UN_TS('user');
									break;
							case 2: str = _UN_TS('mail');
									break;
							case 3: str = _UN_TS('daemon');
									break;
							case 4: str = _UN_TS('auth');
									break;
							case 5: str = _UN_TS('syslog');
									break;
							case 6: str = _UN_TS('lpr');
									break;
							case 7: str = _UN_TS('news');
									break;
							case 8: str = _UN_TS('uucp');
									break;
							case 9: str = _UN_TS('cron');
									break;
							case 10: str = _UN_TS('security');
									break;
							case 11: str = _UN_TS('ftp');
									break;
							case 12: str = _UN_TS('ntp');
									break;
							case 13: str = _UN_TS('logaudit');
									break;
							case 14: str = _UN_TS('logalert');
									break;
							case 15: str = _UN_TS('clock');
									break;
							case 16: str = _UN_TS('local0');
									break;
							case 17: str = _UN_TS('local1');
									break;
							case 18: str = _UN_TS('local2');
									break;
							case 19: str = _UN_TS('local3');
									break;
							case 20: str = _UN_TS('local4');
									break;
							case 21: str = _UN_TS('local5');
									break;
							case 22: str = _UN_TS('local6');
									break;
							case 23: str = _UN_TS('local7');
									break;
						}
						
						metadata.tdAttr = 'data-qtip="' + str + '"';

						return str;
					}
				}, 
				{
					dataIndex: 'progname',
					flex: 2,
					header: _S('SYSLOG_SERVER', 'PROGNAME'),
					renderer: function(value, metadata, record) {
						metadata.tdAttr = 'data-qtip="' + value + '"';
						
						return value;
					}
				}, 
				{
					dataIndex: 'msg',
					flex: 4,
					header: _S('SYSLOG_SERVER', 'MSG'),
					renderer: function(value, metadata, record) {
						metadata.tdAttr = 'data-qtip="' + AS.ARC.util.replaceHtmlSymbols(value) + '"';
						
						return value;
					}
				}
			],
			bbar: Ext.create('AS.ARC.pagingToolbar', {
				border: false
			})
		});

		page.logShowCountButton = Ext.create('Ext.button.Button', {
			text: page.logShowCount,
			menu: [
				{
					text: '10',
					checked: false,
					group: 'logShowSize',
					handler: function() {
						page.logShowCount = 10;
						page.logGrid.store.pageSize = 10;
						page.logGrid.store.loadPage(1);
					},
					listeners: {
						click: function(button, event) {
							page.logShowCountButton.setText(page.logShowCount);
						}
					}
				}, {
					text: '30',
					checked: true,
					group: 'logShowSize',
					handler: function() {
						page.logShowCount = 30;
						page.logGrid.store.pageSize = 30;
						page.logGrid.store.loadPage(1);
					},
					listeners: {
						click: function(button, event) {
							page.logShowCountButton.setText(page.logShowCount);
						}
					}
				}, {
					text: '50',
					checked: false,
					group: 'logShowSize',
					handler: function() {
						page.logShowCount = 50;
						page.logGrid.store.pageSize = 50;
						page.logGrid.store.loadPage(1);
					},
					listeners: {
						click: function(button, event) {
							page.logShowCountButton.setText(page.logShowCount);
						}
					}
				}, {
					text: '100',
					checked: false,
					group: 'logShowSize',
					handler: function() {
						page.logShowCount = 100;
						page.logGrid.store.pageSize = 100;
						page.logGrid.store.loadPage(1);
					},
					listeners: {
						click: function(button, event) {
							page.logShowCountButton.setText(page.logShowCount);
						}
					}
				}, {
					text: '500',
					checked: false,
					group: 'logShowSize',
					handler: function() {
						page.logShowCount = 500;
						page.logGrid.store.pageSize = 500;
						page.logGrid.store.loadPage(1);
					},
					listeners: {
						click: function(button, event) {
							page.logShowCountButton.setText(page.logShowCount);
						}
					}
				}
			]
		});

		page.logGrid.dockedItems.getAt(1).add(
			'-',
			{
				xtype: 'tbtext',
				text: _S('COMMON', 'SHOW'),
				margin: '0 0 0 2',
			},
			page.logShowCountButton,
			{
				xtype: 'tbtext',
				text: _S('COMMON', 'LOW_ITEMS'),
				margin: '0 10 0 2',
			}
		);
        
		return {
			xtype: 'asFnForm',
			page: page,
			itemId:  page.panelItemId,
            title: _S('SYSLOG_SERVER', 'LOG'),
			border: false,
			cls: 'as-page-panel',
			items: [
                logTopCt,
                page.logGrid
            ]
		};
	},

	getOriginStore: function() {
		var page = this;

		var logListStore = Ext.create('Ext.data.JsonStore', {
			autoDestroy: true,
			pageSize: page.logShowCount,
			fields: [
				{name: 'time'},
				{name: 'level'},
				{name: 'fromhostname'},
				{name: 'facility'},
				{name: 'progname'},
				{name: 'msg'}
			],
			remoteSort: true,
			proxy: {
				type: 'ajax',
				url: AS.ARC.util.getApiUrlWithSid(page.fn.apiUrl, {
					act: 'List'
				}),
				reader: {
					type: 'json',
					root: 'list',
					totalProperty: 'count'
				},
				listeners: {
					exception: function(proxy, response, operation, opts) {
						var json = Ext.decode(response.responseText);
						AS.ARC.util.showMsgWindow({
							5000: _S('ERROR', 'SESSION_TIMEOUT'),
							5003: _S('SYSLOG_SERVER', 'SOME_PARAMETER_UNDEFINED'),
							5006: _S('SYSLOG_SERVER', 'CAN_NOT_READ_FILE')
						}, json, page.fn.app.win);
					}
				}
			},
			listeners: {
				beforeload: function() {
					page.logGrid.el.mask(_S('COMMON','LOADING'));

					if (typeof page.logGrid.store.getProxy().extraParams === 'undefined') {
						this.proxy.extraParams = {};
					}

					var sorter = this.sorters.items[0],
						sortType = this.sorters.keys[0],
						sortDefaultValue = typeof sorter === 'undefined',
						sortColumn,
						sortDirection;

					if (sortDefaultValue) {
						sortColumn = 0;
					} else if (sortType === 'level') {
						sortColumn = 1;
					} else if (sortType === 'fromhostname') {
						sortColumn = 2;
					} else if (sortType === 'facility') {
						sortColumn = 3;
					} else if (sortType === 'progname') {
						sortColumn = 4;
					} else if (sortType === 'msg') {
						sortColumn = 5;
					} else {
						sortColumn = 0;
					}

					if (sortDefaultValue) {
						sortDirection = 0;
					} else if (sorter.direction === 'ASC') {
						sortDirection = 1;
					} else {
						sortDirection = 0;
					}

					Ext.apply(this.proxy.extraParams, {
						tab: 'List',
						sort: sortColumn,
						ascend: sortDirection
					});
				},
				load: function(store, records, successful, operation, eOpts) {
					page.logGrid.dockedItems.getAt(1).bindStore(store);
					page.logGrid.bindStore(store);
					page.logGrid.view.el.dom.scrollTop = 0;
					if (page.isNeedToResetLogPanel === true) {
						page.logGrid.dockedItems.getAt(1).moveFirst();
						page.logGrid.up().down('#import').setText(_S('SYSLOG_SERVER', 'LATEST_LOG'));
						page.logGrid.up().down('#import').el.dom.setAttribute('data-qtip', _S('SYSLOG_SERVER', 'LATEST_LOG'));
						page.isNeedToResetLogPanel = false;
					}
					page.logGrid.el.unmask();
				}
			}
		});

		logListStore.load();
	},

	removeColumnsSortState: function() {
		var page = this;

		Ext.each(page.logGrid.columns, function(column) {
			column.sortState = null;
			column.removeCls(["x-column-header-sort-ASC", "x-column-header-sort-DESC"]);
			column.sortable = true;
		});
	},

    loadData: function() {
		var page = this;

		page.isNeedToResetLogPanel = true;
		page.getOriginStore();
		page.removeColumnsSortState();
	}
});

/**
 * @class AS.ARC.apps.syslogServer.log.fn
 * @extends AS.ARC.apps.syslogServer.fn
 * <p></p>
 */
Ext.define('AS.ARC.apps.syslogServer.log.fn', {
	extend: 'AS.ARC.apps.syslogServer.fn',

	fnTag: 'log',
	
	init: function (config) {
		this.apiUrl = AS.ARC.util.getUserAppsPath() + 'syslogServer/syslog-server.cgi';
		this.createPanel();
	},
    
	createPanel: function () {
		var fn = this;
		
		var pageLog = new AS.ARC.apps.syslogServer.log.log({fn: this});
			
		this.tabPanel = Ext.create('AS.ARC.fnTabPanel', {
			items: [
				pageLog.getPanel()
			],
			listeners: {
				tabchange: function(tabpanel) {
					var activeIndex = tabpanel.items.indexOf(tabpanel.getLayout().activeItem);
				},
				resize: function( main, adjWidth, adjHeight, eOpts ) {
					var newHeight = main.getHeight() - 150;
					main.down('#grid').setHeight(newHeight);
					Ps.update(this.el.dom.querySelector('.x-panel-body'));
				}
			}
		});
        
		fn.initMainPanel();
	},
	
	loadData: function () {
		this.tabPanel.activeTab.page.loadData(true);
	}
});