Ext.define('AS.ARC.apps.syslogServer.serversetting.general', {
    extend: 'AS.ARC.apps.syslogServer.page',
	pageTag: 'general',
    imgUrl: AS.ARC.util.getUserAppsPath() + 'syslogServer/images/',
    
	handleApply: function() {
		var page = this,
			urlOpts = {
				act: 'Setting',
            	tab: 'Set_Setting'
			},
			params = page.fp.doDataExchange();

		if (!page.fp.isSettingChange(params)) {
			page.fp.showSetNotChange();
			return false;
		} // end if

		page.fn.app.maskWin(_S('COMMON', 'APPLYING'));
		
        AS.ARC.ajax({
            url: AS.ARC.util.getApiUrlWithSid(AS.ARC.util.getUserAppsPath() + 'syslogServer/syslog-server.cgi', urlOpts),
            method: 'post',
            params: params,
            success: function(json, opts) {
                page.fp.uiChecker.srcData = params;
                page.fp.showApply();
                page.fn.app.unmaskWin();
            },
            failure: function(json, opts) {
                var errors = {
                    5000: _S('ERROR', 'SESSION_TIMEOUT'),
                    5032: _S('ERROR', 'PORT_USED'),
                    5401: _S('ERROR', 'UNABLE_APPLY_SETTINGS')
                };
                
                page.fn.app.unmaskWin();
                AS.ARC.util.showMsgWindow(errors, json, page.fn.app.win, 'warning', function() {page.loadData();});
            }
        });
	},

	getPanel: function() {
		var page = this;

        page.buttonApply = Ext.create('Ext.button.Button', {
			xtype: 'button',
			text: _S('COMMON', 'APPLY')
		});
        
		return {
			xtype: 'asFnForm',
			page: page,
			itemId: page.panelItemId,
            title: _S('COMMON', 'GENERAL'),
			border: false,
			cls: 'as-page-panel',
            buttonAlign: 'left',
			fbar: [
				{
					xtype: 'tbfill'
				},
				page.buttonApply
			],
			items: [
				{
					xtype: 'fieldset',
					itemId: 'syslogServerSettingsFieldset',
					title: _S('SYSLOG_SERVER', 'TRANSMISSION'),
					items: [
						{
							xtype: 'checkbox',
							itemId: 'enableSyslogServerCheckbox',
							boxLabel: _S('SYSLOG_SERVER', 'ENABLE_SERVER'),
							handler: function(checkbox, checked) {
								if (checked) {
									page.enableTCPConnectCheckbox.enable();
									page.enableUDPConnectCheckbox.enable();

									if (page.enableTCPConnectCheckbox.checked) {
										page.connectTCPPortValue.enable();
										page.enableSSLCertificateCheckbox.enable();
									} else {
										page.connectTCPPortValue.disable();
										page.enableSSLCertificateCheckbox.disable();
									}
									
									if (page.enableUDPConnectCheckbox.checked) {
										page.connectUDPPortValue.enable();
									} else {
										page.connectUDPPortValue.disable();
									}
								} else {
									page.enableTCPConnectCheckbox.disable();
									page.connectTCPPortValue.disable();
									page.enableUDPConnectCheckbox.disable();
									page.connectUDPPortValue.disable();
									page.enableSSLCertificateCheckbox.disable();
								}
							}
						}, 
						{
							xtype: 'checkbox',
							itemId: 'enableTCPConnectCheckbox',
							boxLabel: _S('SYSLOG_SERVER', 'ENABLE_TCP'),
							style: 'margin-left: 20px',
							handler: function(checkbox, checked) {
								if (checked) {
									page.connectTCPPortValue.enable();
									page.enableSSLCertificateCheckbox.enable();
									page.connectTCPPortValue.clearInvalid();
								} else {
									page.connectTCPPortValue.disable();
									page.enableSSLCertificateCheckbox.disable();
									page.connectTCPPortValue.clearInvalid();
								}
							}
						}, 
						{
							xtype: 'numberfield',
							itemId: 'connectTCPPortValue',
							msgTarget: AS.ARC.config.msgTarget,
							fieldLabel: _S('COMMON', 'PORT'),
							value: '514',
							style: 'margin-left: 40px',
							validator: function(value) {
								if (value < 1 || value > 65535) {
									return _S('MESSAGE', 'HF00001');
								} else {
									return true;
								}
							}
						}, 
						{
							xtype: 'checkbox',
							itemId: 'enableSSLCertificateCheckbox',
							boxLabel: _S('SYSLOG_SERVER', 'ENABLE_SSL'),
							style: 'margin-left: 40px'
						}, 
						{
							xtype: 'checkbox',
							itemId: 'enableUDPConnectCheckbox',
							boxLabel: _S('SYSLOG_SERVER', 'ENABLE_UDP'),
							style: 'margin-left: 20px',
							handler: function(checkbox, checked) {
								if (checked) {
									page.connectUDPPortValue.enable();
									page.connectUDPPortValue.clearInvalid();
								} else {
									page.connectUDPPortValue.disable();
									page.connectUDPPortValue.clearInvalid();
								}
							}
						}, 
						{
							xtype: 'numberfield',
							itemId: 'connectUDPPortValue',
							fieldLabel: _S('COMMON', 'PORT'),
							msgTarget: AS.ARC.config.msgTarget,
							value: '514',
							style: 'margin-left: 40px',
							validator: function(value) {
								if (value < 1 || value > 65535) {
									return _S('MESSAGE', 'HF00001');
								} else {
									return true;
								}
							}
						}
					]
				}, 
				{
					xtype: 'fieldset',
					itemId: 'exportSSLFieldset',
					title: _S('SYSLOG_SERVER', 'EXPORT'),
					layout: 'vbox',
					height: 100,
					items: [
						{
							xtype: 'displayfield',
							value: _S('SYSLOG_SERVER', 'EXPORT_HINT')
						}, 
						{
							xtype: 'asPanelToolbarTop',
							cls: 'as-tooltopbar-common-layout-3-0',
							border: false,
							items: [
								{
									xtype: 'button',
									text: _S('SYSLOG_SERVER', 'EXPORT'),
									handler: function() {
										var download = Ext.create('Ext.form.FormPanel', {
												items: [
													{
														xtype: 'filefield'
													}
												]
											}),
											uform = download.getForm();
		
										var doSubmit = function() {
											uform.submit({
												url: AS.ARC.util.getApiUrlWithSid(page.fn.apiUrl, {act: 'Setting', tab: 'Exprot_Cert'}),
												success: function(fp, o) {
		
												},
												failure: function(form, action) {
													var json = Ext.decode(action.response.responseText);
		
													AS.ARC.util.showMsgWindow({
														5000: _S('ERROR', 'SESSION_TIMEOUT')
													}, json, page.fn.app.win);
												}
											});
										};
		
										doSubmit();
									}
								}
							]
						}
					]
				}
			],
            doDataExchange: function() {
				var enableSyslogServer,
					enableTCPConnect,
					enableUDPConnect,
					enableSSLCertificate,
					connectTCPPort = page.connectTCPPortValue.getValue(),
					connectUDPPort = page.connectUDPPortValue.getValue();

				enableSyslogServer = page.enableSyslogServerCheckbox.checked ? 1 : 0;

				enableTCPConnect = page.enableTCPConnectCheckbox.checked ? 1 : 0;

				enableUDPConnect = page.enableUDPConnectCheckbox.checked ? 1 : 0;

				enableSSLCertificate = page.enableSSLCertificateCheckbox.checked ? 1 : 0;

				var pageData = {
                    enable_server: enableSyslogServer, 
                    enable_tcp: enableTCPConnect, 
                    enable_ssl: enableSSLCertificate, 
                    tcp_port: connectTCPPort, 
                    enable_udp: enableUDPConnect, 
                    udp_port: connectUDPPort
                };
                
				return pageData;
			}
		};
	},

	loadData: function() {
		var page = this;
		
		page.fn.app.maskWin(_S('COMMON', 'LOADING'));

		page.enableSyslogServerCheckbox = page.fn.tabPanel.down('#enableSyslogServerCheckbox');
		page.enableTCPConnectCheckbox = page.fn.tabPanel.down('#enableTCPConnectCheckbox');
		page.connectTCPPortValue = page.fn.tabPanel.down('#connectTCPPortValue');
		page.enableSSLCertificateCheckbox = page.fn.tabPanel.down('#enableSSLCertificateCheckbox');
		page.enableUDPConnectCheckbox = page.fn.tabPanel.down('#enableUDPConnectCheckbox');
		page.connectUDPPortValue = page.fn.tabPanel.down('#connectUDPPortValue');
        
        AS.ARC.ajax({
            url: AS.ARC.util.getApiUrlWithSid(AS.ARC.util.getUserAppsPath() + 'syslogServer/syslog-server.cgi', {act: 'Setting', tab: 'Get_Setting'}),
            method: 'post',
            success: function(json, opts) {
                page.fp.uiChecker.srcData = json;
                
                if (json.enable_server === 1) {
                    page.enableSyslogServerCheckbox.setValue(true);
					page.enableTCPConnectCheckbox.enable();
					page.enableUDPConnectCheckbox.enable();
                } else {
                    page.enableSyslogServerCheckbox.setValue(false);
					page.enableTCPConnectCheckbox.disable();
					page.enableUDPConnectCheckbox.disable();
                }
                        
                if (json.enable_tcp === 1) {
                    page.enableTCPConnectCheckbox.setValue(true);

					if (json.enable_server === 1) {
						page.connectTCPPortValue.enable();
						page.enableSSLCertificateCheckbox.enable();
					} else {
						page.connectTCPPortValue.disable();
						page.enableSSLCertificateCheckbox.disable();
					}
                } else {
                    page.enableTCPConnectCheckbox.setValue(false);
					page.connectTCPPortValue.disable();
					page.enableSSLCertificateCheckbox.disable();
                }
                        
                page.connectTCPPortValue.setValue(json.tcp_port);
                        
                if (json.enable_ssl === 1) {
                    page.enableSSLCertificateCheckbox.setValue(true);
                } else {
                    page.enableSSLCertificateCheckbox.setValue(false);
                }
                        
                if (json.enable_udp === 1) {
                    page.enableUDPConnectCheckbox.setValue(true);
					
					if (json.enable_server === 1) {
						page.connectUDPPortValue.enable();
					} else {
						page.connectUDPPortValue.disable();
					}
                } else {
                    page.enableUDPConnectCheckbox.setValue(false);
					page.connectUDPPortValue.disable();
				}
				
				page.connectUDPPortValue.setValue(json.udp_port);
                
                page.connectTCPPortValue.clearInvalid();
				page.connectUDPPortValue.clearInvalid();
				
				page.fn.app.unmaskWin();
            },
            failure: function(json, opts) {
				page.fn.app.unmaskWin();
                AS.ARC.util.showMsgWindow({
                    5000: _S('ERROR', 'SESSION_TIMEOUT'),
                    5006: _S('SYSLOG_SERVER', 'CAN_NOT_READ_FILE')
                }, json, page.fn.app.win);
            }
        });
	}
});

Ext.define('AS.ARC.apps.syslogServer.serversetting.filter', {
    extend: 'AS.ARC.apps.syslogServer.page',
	pageTag: 'filter',
    imgUrl: AS.ARC.util.getUserAppsPath() + 'syslogServer/images/',
	getPanel: function() {
		var page = this;
		
		var filterFacilityItem = function() {
			return {
				xtype: 'container',
				width: 500,
				layout: 'column',
				itemId: 'filterFacilityItem',
				defaults: {
					margin: '0 0 0 5'
				},
				items: [
					{
						xtype: 'displayfield',
						width: 250,
						value: _S('SYSLOG_SERVER', 'FACILITY') + ':'
					}, 
					{
						xtype: 'combobox',
						itemId: 'operator',
						width: 100,
						store: {
							fields: ['value', 'text'],
							data: [
								{'value':'equal', 'text': _S('SYSLOG_SERVER', 'EQUAL')},
								{'value': 'notequal', 'text': _S('SYSLOG_SERVER', 'NOTEQUAL')}
							]
						},
						editable: false,
						value: 'equal',
						triggerAction: 'all',
						valueField: 'value',
						displayField: 'text'
					}, 
					{
						xtype: 'combobox',
						itemId: 'val',
						width: 100,
						store: {
							fields: ['value', 'text'],
							data: [
								{'value': '', 'text': ''},
								{'value': 'auth', 'text': 'auth'},
								{'value': 'authpriv', 'text': 'authpriv'},
								{'value': 'cron', 'text': 'cron'},
								{'value': 'daemon', 'text': 'daemon'},
								{'value': 'ftp', 'text': 'ftp'},
								{'value': 'kern', 'text': 'kern'},
								{'value': 'lpr', 'text': 'lpr'},
								{'value': 'mail', 'text': 'mail'},
								{'value': 'news', 'text': 'news'},
								{'value': 'security', 'text': 'security'},
								{'value': 'syslog', 'text': 'syslog'},
								{'value': 'user', 'text': 'user'},
								{'value': 'uucp', 'text': 'uucp'},
								{'value': 'local0', 'text': 'local0'},
								{'value': 'local1', 'text': 'local1'},
								{'value': 'local2', 'text': 'local2'},
								{'value': 'local3', 'text': 'local3'},
								{'value': 'local4', 'text': 'local4'},
								{'value': 'local5', 'text': 'local5'},
								{'value': 'local6', 'text': 'local6'},
								{'value': 'local7', 'text': 'local7'}
							]
						},
						editable: false,
						value: '',
						triggerAction: 'all',
						valueField: 'value',
						displayField: 'text'
					}
				]
			}
		}
		
		var filterSeverityItem = function() {
			return {
				xtype: 'container',
				width: 500,
				layout: 'column',
				itemId: 'filterSeverityItem',
				defaults: {
					margin: '0 0 0 5'
				},
				items: [
					{
						xtype: 'displayfield',
						width: 250,
						value: _S('SYSLOG_SERVER', 'SEVERITY') + ':'
					}, 
					{
						xtype: 'combobox',
						itemId: 'operator',
						width: 100,
						store: {
							fields: ['value', 'text'],
							data: [
								{'value':'higher', 'text': _S('SYSLOG_SERVER', 'HIGHER')},
								{'value': 'lower', 'text': _S('SYSLOG_SERVER', 'LOWER')},
								{'value':'equal', 'text': _S('SYSLOG_SERVER', 'EQUAL')},
								{'value': 'notequal', 'text': _S('SYSLOG_SERVER', 'NOTEQUAL')}
							]
						},
						editable: false,
						value: 'higher',
						triggerAction: 'all',
						valueField: 'value',
						displayField: 'text'
					}, 
					{
						xtype: 'combobox',
						itemId: 'val',
						width: 100,
						store: {
							fields: ['value', 'text'],
							data: [
								{'value': '', 'text': ''},
								{'value': 'emerg', 'text': _UN_TS('Emerg')},
								{'value': 'alert', 'text': _UN_TS('Alert')},
								{'value': 'crit', 'text': _UN_TS('Crit')},
								{'value': 'err', 'text': _UN_TS('Err')},
								{'value': 'warning', 'text': _UN_TS('Warning')},
								{'value': 'notice', 'text': _UN_TS('Notice')},
								{'value': 'info', 'text': _UN_TS('Info')},
								{'value': 'debug', 'text': _UN_TS('Debug')}
							]
						},
						editable: false,
						value: '',
						triggerAction: 'all',
						valueField: 'value',
						displayField: 'text'
					}
				]
			}
		}
		
		var filterNameItem = function() {
			return {
				xtype: 'container',
				width: 500,
				layout: 'column',
				itemId: 'filterNameItem',
				defaults: {
					margin: '0 0 0 5'
				},
				items: [
					{
						xtype: 'displayfield',
						width: 250,
						value: _S('SYSLOG_SERVER', 'FROM_HOST_NAME') + ':'
					}, 
					{
						xtype: 'combobox',
						itemId: 'operator',
						width: 100,
						store: {
							fields: ['value', 'text'],
							data: [
								{'value':'equal', 'text': _S('SYSLOG_SERVER', 'EQUAL')},
								{'value': 'notequal', 'text': _S('SYSLOG_SERVER', 'NOTEQUAL')}
							]
						},
						editable: false,
						value: 'equal',
						triggerAction: 'all',
						valueField: 'value',
						displayField: 'text'
					}, 
					{
						xtype: 'textfield',
						itemId: 'val',
						width: 100
					}
				]
			}
		}
		
		var filterProgramnameItem = function() {
			return {
				xtype: 'container',
				width: 500,
				layout: 'column',
				itemId: 'filterProgramnameItem',
				defaults: {
					margin: '0 0 0 5'
				},
				items: [
					{
						xtype: 'displayfield',
						width: 250,
						value: _S('SYSLOG_SERVER', 'SERVICE') + ':'
					}, 
					{
						xtype: 'combobox',
						itemId: 'operator',
						width: 100,
						store: {
							fields: ['value', 'text'],
							data: [
								{'value':'equal', 'text': _S('SYSLOG_SERVER', 'EQUAL')},
								{'value': 'notequal', 'text': _S('SYSLOG_SERVER', 'NOTEQUAL')}
							]
						},
						editable: false,
						value: 'equal',
						triggerAction: 'all',
						valueField: 'value',
						displayField: 'text'
					}, 
					{
						xtype: 'textfield',
						itemId: 'val',
						width: 100
					}
				]
			}
		}
		
		var filterMsgItem = function() {
			return {
				xtype: 'container',
				width: 500,
				layout: 'column',
				itemId: 'filterMsgItem',
				defaults: {
					margin: '0 0 0 5'
				},
				items: [
					{
						xtype: 'displayfield',
						width: 250,
						value: _S('SYSLOG_SERVER', 'MSG') + ':'
					}, 
					{
						xtype: 'combobox',
						itemId: 'operator',
						width: 100,
						store: {
							fields: ['value', 'text'],
							data: [
								{'value':'contains', 'text': _S('SYSLOG_SERVER', 'CONTAINS')},
								{'value': 'notcontains', 'text': _S('SYSLOG_SERVER', 'NOTCONTAINS')}
							]
						},
						editable: false,
						value: 'contains',
						triggerAction: 'all',
						valueField: 'value',
						displayField: 'text'
					}, 
					{
						xtype: 'textfield',
						itemId: 'val',
						width: 100
					}
				]
			}
		}
		
		var filterIpItem = function() {
			return {
				xtype: 'container',
				width: 500,
				layout: 'column',
				itemId: 'filterIpItem',
				defaults: {
					margin: '0 0 0 5'
				},
				items: [
					{
						xtype: 'displayfield',
						width: 250,
						value: _S('SYSLOG_SERVER', 'IP') + ':'
					}, 
					{
						xtype: 'combobox',
						itemId: 'operator',
						width: 100,
						store: {
							fields: ['value', 'text'],
							data: [
								{'value':'equal', 'text': _S('SYSLOG_SERVER', 'EQUAL')},
								{'value': 'startwith', 'text': _S('SYSLOG_SERVER', 'STARTWITH')},
								{'value':'contains', 'text': _S('SYSLOG_SERVER', 'CONTAINS')},
								{'value': 'notequal', 'text': _S('SYSLOG_SERVER', 'NOTEQUAL')},
								{'value':'notstartwith', 'text': _S('SYSLOG_SERVER', 'NOTSTARTWITH')},
								{'value': 'notcontains', 'text': _S('SYSLOG_SERVER', 'NOTCONTAINS')}
							]
						},
						editable: false,
						value: 'equal',
						triggerAction: 'all',
						valueField: 'value',
						displayField: 'text'
					}, 
					{
						xtype: 'textfield',
						itemId: 'val',
						width: 100
					}
				]
			}
		}
		
		var getFilterAddWin = function() {
			var filterAddWin = Ext.create('AS.ARC.subWindow', {
				title: _S('COMMON', 'FILTER'),
				width: 600,
				height: 415,
				parentWin: page.fn.app.win,
				layout: 'vbox',
				onEsc: function() {
				},
				fbar: [
					{
						xtype: 'button',
						itemId: 'search',
						text: _S('COMMON', 'APPLY'),
						handler: function() {

							var str;
							var strAry = [];
							var filterFacilityVal = filterAddWin.items.get('filterItems').items.get('filterFacilityItem').items.get('val');
							var filterFacilityOp = filterAddWin.items.get('filterItems').items.get('filterFacilityItem').items.get('operator');
							var filterSeverityVal = filterAddWin.items.get('filterItems').items.get('filterSeverityItem').items.get('val');
							var filterSeverityOp = filterAddWin.items.get('filterItems').items.get('filterSeverityItem').items.get('operator');
							var filterNameVal = filterAddWin.items.get('filterItems').items.get('filterNameItem').items.get('val');
							var filterNameOp = filterAddWin.items.get('filterItems').items.get('filterNameItem').items.get('operator');
							var filterProgramnameVal = filterAddWin.items.get('filterItems').items.get('filterProgramnameItem').items.get('val');
							var filterProgramnameOp = filterAddWin.items.get('filterItems').items.get('filterProgramnameItem').items.get('operator');
							var filterMsgVal = filterAddWin.items.get('filterItems').items.get('filterMsgItem').items.get('val');
							var filterMsgOp = filterAddWin.items.get('filterItems').items.get('filterMsgItem').items.get('operator');
							var filterIpVal = filterAddWin.items.get('filterItems').items.get('filterIpItem').items.get('val');
							var filterIpOp = filterAddWin.items.get('filterItems').items.get('filterIpItem').items.get('operator');
							
							if (filterFacilityVal.getValue() != '') {
								if(filterFacilityOp.getValue() == 'equal') {
									str = '($syslogfacility-text == ' + "'" + filterFacilityVal.getValue() + "')";
									strAry.push(str);
								} else if(filterFacilityOp.getValue() == 'notequal') {
									str = 'not ($syslogfacility-text == ' + "'" + filterFacilityVal.getValue() + "')";
									strAry.push(str);
								}
							}

							if(filterSeverityVal.getValue() != '') {
								if(filterSeverityOp.getValue() == 'higher') {
									str = '($syslogseverity-text <= ' + "'" + filterSeverityVal.getValue() + "')";
									strAry.push(str);
								} else if(filterSeverityOp.getValue() == 'lower') {
									str = 'not ($syslogseverity-text <= ' + "'" + filterSeverityVal.getValue() + "')";
									strAry.push(str);
								} else if(filterSeverityOp.getValue() == 'equal') {
									str = '($syslogseverity-text == ' + "'" + filterSeverityVal.getValue() + "')";
									strAry.push(str);
								} else if(filterSeverityOp.getValue() == 'notequal') {
									str = 'not ($syslogseverity-text == ' + "'" + filterSeverityVal.getValue() + "')";
									strAry.push(str);
								}
							}

							if (filterNameVal.getValue() != '') {
								if(filterNameOp.getValue() == 'equal') {
									str = '($hostname == ' + "'" + filterNameVal.getValue() + "')";
									strAry.push(str);
								} else if(filterNameOp.getValue() == 'startwith') {
									str = '($hostname startwith ' + "'" + filterNameVal.getValue() + "')";
									strAry.push(str);
								} else if(filterNameOp.getValue() == 'contains') {
									str = '($hostname contains ' + "'" + filterNameVal.getValue() + "')";
									strAry.push(str);
								} else if(filterNameOp.getValue() == 'notequal') {
									str = 'not ($hostname == ' + "'" + filterNameVal.getValue() + "')";
									strAry.push(str);
								} else if(filterNameOp.getValue() == 'notstartwith') {
									str = 'not ($hostname startwith ' + "'" + filterNameVal.getValue() + "')";
									strAry.push(str);
								} else if(filterNameOp.getValue() == 'notcontains') {
									str = 'not ($hostname contains ' + "'" + filterNameVal.getValue() + "')";
									strAry.push(str);
								}
							}

							if (filterProgramnameVal.getValue() != '') {
								if(filterProgramnameOp.getValue() == 'equal') {
									str = '($programname == ' + "'" + filterProgramnameVal.getValue() + "')";
									strAry.push(str);
								} else if(filterProgramnameOp.getValue() == 'startwith') {
									str = '($programname startwith ' + "'" + filterProgramnameVal.getValue() + "')";
									strAry.push(str);
								} else if(filterProgramnameOp.getValue() == 'contains') {
									str = '($programname contains ' + "'" + filterProgramnameVal.getValue() + "')";
									strAry.push(str);
								} else if(filterProgramnameOp.getValue() == 'notequal') {
									str = 'not ($programname == ' + "'" + filterProgramnameVal.getValue() + "')";
									strAry.push(str);
								} else if(filterProgramnameOp.getValue() == 'notstartwith') {
									str = 'not ($programname startwith ' + "'" + filterProgramnameVal.getValue() + "')";
									strAry.push(str);
								} else if(filterProgramnameOp.getValue() == 'notcontains') {
									str = 'not ($programname contains ' + "'" + filterProgramnameVal.getValue() + "')";
									strAry.push(str);
								}
							}


							if (filterMsgVal.getValue() != '') {
								if(filterMsgOp.getValue() == 'equal') {
									str = '($msg == ' + "'" + filterMsgVal.getValue() + "')";
									strAry.push(str);
								} else if(filterMsgOp.getValue() == 'startwith') {
									str = '($msg startwith ' + "'" + filterMsgVal.getValue() + "')";
									strAry.push(str);
								} else if(filterMsgOp.getValue() == 'contains') {
									str = '($msg contains ' + "'" + filterMsgVal.getValue() + "')";
									strAry.push(str);
								} else if(filterMsgOp.getValue() == 'notequal') {
									str = 'not ($msg == ' + "'" + filterMsgVal.getValue() + "')";
									strAry.push(str);
								} else if(filterMsgOp.getValue() == 'notstartwith') {
									str = 'not ($msg startwith ' + "'" + filterMsgVal.getValue() + "')";
									strAry.push(str);
								} else if(filterMsgOp.getValue() == 'notcontains') {
									str = 'not ($msg contains ' + "'" + filterMsgVal.getValue() + "')";
									strAry.push(str);
								}
							}


							if (filterIpVal.getValue() != '') {
								if(filterIpOp.getValue() == 'equal') {
									str = '($fromhost-ip == ' + "'" + filterIpVal.getValue() + "')";
									strAry.push(str);
								} else if(filterIpOp.getValue() == 'startwith') {
									str = '($fromhost-ip startwith ' + "'" + filterIpVal.getValue() + "')";
									strAry.push(str);
								} else if(filterIpOp.getValue() == 'contains') {
									str = '($fromhost-ip contains ' + "'" + filterIpVal.getValue() + "')";
									strAry.push(str);
								} else if(filterIpOp.getValue() == 'notequal') {
									str = 'not ($fromhost-ip == ' + "'" + filterIpVal.getValue() + "')";
									strAry.push(str);
								} else if(filterIpOp.getValue() == 'notstartwith') {
									str = 'not ($fromhost-ip startwith ' + "'" + filterIpVal.getValue() + "')";
									strAry.push(str);
								} else if(filterIpOp.getValue() == 'notcontains') {
									str = 'not ($fromhost-ip contains ' + "'" + filterIpVal.getValue() + "')";
									strAry.push(str);
								}
							}

							var result = 'if (' + strAry.join(' and ') + ' )';


							if (strAry.length != 0) {
								AS.ARC.ajax({
									url: AS.ARC.util.getApiUrlWithSid(AS.ARC.util.getUserAppsPath() + 'syslogServer/syslog-server.cgi', {act: 'Setting', tab: 'Filter', filter: 'add_rule', rule: result}),
									method: 'post',
									success: function (json, opts) {
											filterGrid.store.load();
									},
									failure: function (json, opts) {
										AS.ARC.util.showMsgWindow({
											5000: _S('ERROR', 'SESSION_TIMEOUT'),
											5006: _S('SYSLOG_SERVER', 'CAN_NOT_READ_FILE'),
											5302: _S('ERROR', 'INCORRECT_PARAMETER'),
											5401: _S('ERROR', 'UNABLE_APPLY_SETTINGS')
										}, json, page.fn.win);
									}
								});
							}
							filterAddWin.close();
						}	

					}, 
					{
						xtype: 'button',
						text: _S('COMMON', 'CANCEL'),
						handler: function() {
							filterAddWin.close();
						}
					}
				],
				items: [
					{
						xtype: 'panel',
						itemId: 'filterItems',
						
						width: 600,
						height: 365,
						autoScroll: true,
						bodyStyle: 'padding: 15px',
						items: [
							filterFacilityItem(),
							filterSeverityItem(),
							filterNameItem(),
							filterProgramnameItem(),
							filterMsgItem(),
							filterIpItem()
						]
					}
				]
			});
			
			filterAddWin.show();
		};
		
		var filterTopCt = Ext.create(AS.ARC.panelToolbarTop, {
			itemId: 'filterTopCt',
			layout: 'hbox',
			items: [
				{
					xtype: 'button',
					text: _S('COMMON', 'ADD'),
					handler: function() {
						getFilterAddWin();
					}
				},
				{
					xtype: 'button',
					itemId: 'removeFilterItemBtn',
					text: _S('COMMON', 'REMOVE'),
					disabled: true,
					handler: function() {
						if(filterGrid.getSelectionModel().getCount() === 0) {
							return;
						}
						
						//var rule = filterGrid.getSelectionModel().getSelection().data.rule;
						Ext.each(filterGrid.getSelectionModel().getSelection(), function(r) {
							AS.ARC.ajax({
								url: AS.ARC.util.getApiUrlWithSid(AS.ARC.util.getUserAppsPath() + 'syslogServer/syslog-server.cgi', {act: 'Setting', tab: 'Filter', filter: 'remove_rule', rule: r.data.rule}),
								method: 'post',
								success: function(json, opts) {
									filterGrid.store.load();
								},
								failure: function() {

								}
							});
						});
					}
				}
			]
		});
		
		var filterStore = Ext.create('Ext.data.JsonStore', {
			autoDestroy: true,
			fields: [
				{name: 'rule'},
				{name: 'enable_rule'},
			],
			proxy: {
				type: 'ajax',
				url: AS.ARC.util.getApiUrlWithSid(AS.ARC.util.getUserAppsPath() + 'syslogServer/syslog-server.cgi', {
					act: 'Setting',
					tab: 'Filter',
					filter: 'list_rule'
				}),
				reader: {
					type: 'json',
					root: 'data',
				}
			},
			listeners: {
				beforeload: function() {
					var removeFilterButton = filterTopCt.down('#removeFilterItemBtn');

					removeFilterButton.setDisabled(true);
					filterGrid.el.mask(_S('COMMON','LOADING'));
				},
				load: function() {
					filterGrid.el.unmask();
				}
			}
		});
		
		var filterGrid = Ext.create(Ext.grid.GridPanel, {
			itemId: 'grid',
			height: 400,
			cls: 'as-grid',
			border: false,
			columns: [
				{
					xtype: 'checkcolumn',
					dataIndex: 'enable_rule',
					flex: 1,
					header: _S('COMMON', 'ENABLE'),
					listeners: {
						checkchange: function( comp, rowIndex, checked, eOpts ) {
							
							var models = filterGrid.getStore().getRange();
							
							if(checked) {
								
								AS.ARC.ajax({
									url: AS.ARC.util.getApiUrlWithSid(AS.ARC.util.getUserAppsPath() + 'syslogServer/syslog-server.cgi', {act: 'Setting', tab: 'Filter', filter: 'modify_rule_enable', rule: models[rowIndex].data.rule, enable_rule: 1}),
									method: 'post',
									success: function(json, opts) {
										filterGrid.store.load();
									},
									failure: function() {

									}
								});
							} else {
								AS.ARC.ajax({
									url: AS.ARC.util.getApiUrlWithSid(AS.ARC.util.getUserAppsPath() + 'syslogServer/syslog-server.cgi', {act: 'Setting', tab: 'Filter', filter: 'modify_rule_enable', rule: models[rowIndex].data.rule, enable_rule: 0}),
									method: 'post',
									success: function(json, opts) {
										filterGrid.store.load();
									},
									failure: function() {

									}
								});
							}
						}
					}
				}, 
				{
					dataIndex: 'rule',
					flex: 6,
					header: _S('SYSLOG_SERVER', 'FILTER_RULE'),
					renderer: function(value, metadata) {
						if(value == '') {
							return 'no value';
						} else {
							metadata.tdAttr = 'data-qtip="' + value + '"';
							return value;
						}
					}
				}, 
				{
					dataIndex: 'enable_rule',
					flex: 1,
					header: _S('COMMON', 'STATUS'),
					renderer: function(value) {
						if(value == 0) {
							return _S('COMMON', 'DISABLE');
						} else {
							return _S('COMMON', 'ENABLE');
						}
					}
				}
			],
			store: filterStore,
			bbar: Ext.create('AS.ARC.pagingToolbar', {
				border: false,
				store: filterStore,
			}),
			listeners: {
				render: function() {
					filterGrid.store.load();
				},
				selectionchange: function(selectionModel, selected, eOpts) {
					var removeFilterButton = filterTopCt.down('#removeFilterItemBtn'),
						isSelectedFilterItem = selectionModel.hasSelection();

					removeFilterButton.setDisabled(!isSelectedFilterItem);
				}
			}
		});
		
		return {
			xtype: 'asFnForm',
			page: page,
			itemId: page.panelItemId,
            title: _S('SYSLOG_SERVER', 'FILTER_RULE'),
			border: false,
			cls: 'as-page-panel',
			items: [
                filterTopCt,
				filterGrid
            ]
		};
	}
});

/**
 * @class AS.ARC.apps.syslogServer.serversettings.fn
 * @extends AS.ARC.apps.syslogServer.fn
 * <p></p>
 */
Ext.define('AS.ARC.apps.syslogServer.serversetting.fn', {
	extend: 'AS.ARC.apps.syslogServer.fn',

	fnTag: 'serversetting',
	
	init: function (config) {
		this.apiUrl = AS.ARC.util.getUserAppsPath() + 'syslogServer/syslog-server.cgi';
		this.createPanel();
	},
    
	createPanel: function () {
		var fn = this;
		
		var pageGeneral = new AS.ARC.apps.syslogServer.serversetting.general({fn: this});
		var pageFilter = new AS.ARC.apps.syslogServer.serversetting.filter({fn: this});
			
		this.tabPanel = Ext.create('AS.ARC.fnTabPanel', {
			items: [
				pageGeneral.getPanel(),
				pageFilter.getPanel()
			]
		});
        
		fn.initMainPanel();
	},
	
	loadData: function () {
		this.tabPanel.activeTab.page.loadData(true);
	}
});